Module annotation

Module annotation 

Module containing types and functions for annotations of tasks

Structs

Annotation
Annotation type for task annotations. Each annotation in taskwarrior consists of a date and a description, the date is named “entry”, the description “description” in the JSON export.