[−][src]Function task_hookrs::tw::run_query_cmd
pub fn run_query_cmd(cmd: Command) -> Result<Vec<Task>>
This executes the given Command and trys to convert the Result into a Vec
pub fn run_query_cmd(cmd: Command) -> Result<Vec<Task>>
This executes the given Command and trys to convert the Result into a Vec