[−][src]Function task_hookrs::tw::save_async
pub fn save_async<'a, T>(tasks: T) -> Result<Child> where
T: IntoIterator<Item = &'a Task>,
This function returns the handle to a child process which saves the given tasks.
pub fn save_async<'a, T>(tasks: T) -> Result<Child> where
T: IntoIterator<Item = &'a Task>,
This function returns the handle to a child process which saves the given tasks.